/** \file Data.h
    \brief Acquired oscilloscope data
*/

#ifndef DataH
#define DataH

#include <vector>

class Data
{
public:
	Data();
	int GetBitsPerSample (void) {
		return iBitsPerSample;
	}
    unsigned int GetChannelCount (void) const {
        return iChannelCount;
    }
	void SetBitsPerSample(int bits)
	{
    	iBitsPerSample = bits;
	}
	/** \brief Allocate/re-initialize all channels */
	void SetChannelCount(int ch_count);

	enum MODE {
		MODE_OSCILLOSCOPE = 0,  ///< plot versus time
		MODE_SPECTRUM,          ///< plot versus frequency
		MODE_RECORDER			///< plot versus time, slow changing signal recorder		
	};

	struct Channel {
		Channel() { bEnabled = true; }
		bool bEnabled;							///< de-/activating channel
		int iCouplingType;						///< coupling type
		float fOffset, fZoom;					///< display zoom and offset
		std::vector<float> dataOsc;             ///< data container used in oscilloscope and slow signal recorder modes
		std::vector<float> dataOscTmp;			///< temporary container for samples
		std::vector<float> dataFFT;             ///< data container used in spectrum analyzer mode
		std::vector<float> dataRec;             ///< data container used in slow changing signal recorder mode
	};
	float fOscDivX;								///< sampling interval (oscilloscope mode)
    float fRecorderInterval;

	bool bFrameFilled;

private:
	int iBitsPerSample;
	int iChannelCount;
	std::vector<Channel> channels;
	enum MODE mode;

public:
	struct Channel& getChannel(int id)
	{
		return channels[id];
	}
	const struct Channel& getChannelConst(int id) const
	{
		return channels[id];
	}
	void SetMode(enum MODE mode)
	{
		this->mode = mode;
	}
	enum MODE GetMode(void) const
    {
    	return mode;
	}
};

#endif // DataH
